@@ -40,10 +40,13 @@ def parse_config():
         os.path.join(os.path.expanduser("~"), ".sd-upload-config.yaml"),
         "sd-upload-config.yml",
         "sd-upload-config.yaml",
-         "/opt/robin/config/sd-upload",
-         "/opt/robin/config/sd-upload",
-        "/opt/robin/config/sd-upload/sd-upload-config.yml",
-        "/opt/robin/config/sd-upload/sd-upload-config.yaml"
+        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config.yml"),
+        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config.yaml"),
+        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "config.yml"),
+        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "config.yaml"),
+        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "config"),
+        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config"),
+        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config"),
     ]
 
     config = None
